==> com.liferay.headless.commerce.admin.catalog.impl-4.0.86-sources.jar: com/liferay/headless/commerce/admin/catalog/internal/dto/v1_0/converter/constants/DTOConverterConstants.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.headless.commerce.admin.catalog.internal.dto.v1_0.converter.constants;

/**
 * @author Pedro Victor Silvestre
 */
public class DTOConverterConstants {

	public static final String MAPPED_PRODUCT_DTO_CONVERTER =
		"(component.name=com.liferay.headless.commerce.admin.catalog." +
			"internal.dto.v1_0.converter.MappedProductDTOConverter)";

	public static final String OPTION_CATEGORY_DTO_CONVERTER =
		"(component.name=com.liferay.headless.commerce.admin.catalog." +
			"internal.dto.v1_0.converter.OptionCategoryDTOConverter)";

	public static final String PRODUCT_SPECIFICATION_DTO_CONVERTER =
		"(component.name=com.liferay.headless.commerce.admin.catalog." +
			"internal.dto.v1_0.converter.ProductSpecificationDTOConverter)";

	public static final String SKU_DTO_CONVERTER =
		"(component.name=com.liferay.headless.commerce.admin.catalog." +
			"internal.dto.v1_0.converter.SkuDTOConverter)";

}

==> com.liferay.headless.commerce.admin.catalog.impl-4.0.131-sources.jar: com/liferay/headless/commerce/admin/catalog/internal/dto/v1_0/converter/constants/DTOConverterConstants.java <==
/**
 * SPDX-FileCopyrightText: (c) 2000 Liferay, Inc. https://liferay.com
 * SPDX-License-Identifier: LGPL-2.1-or-later OR LicenseRef-Liferay-DXP-EULA-2.0.0-2023-06
 */

package com.liferay.headless.commerce.admin.catalog.internal.dto.v1_0.converter.constants;

/**
 * @author Pedro Victor Silvestre
 * @author Alessio Antonio Rendina
 */
public class DTOConverterConstants {

	public static final String MAPPED_PRODUCT_DTO_CONVERTER =
		"(component.name=com.liferay.headless.commerce.admin.catalog." +
			"internal.dto.v1_0.converter.MappedProductDTOConverter)";

	public static final String OPTION_CATEGORY_DTO_CONVERTER =
		"(component.name=com.liferay.headless.commerce.admin.catalog." +
			"internal.dto.v1_0.converter.OptionCategoryDTOConverter)";

	public static final String PRODUCT_OPTION_VALUE_DTO_CONVERTER =
		"(component.name=com.liferay.headless.commerce.admin.catalog." +
			"internal.dto.v1_0.converter.ProductOptionValueDTOConverter)";

	public static final String PRODUCT_SPECIFICATION_DTO_CONVERTER =
		"(component.name=com.liferay.headless.commerce.admin.catalog." +
			"internal.dto.v1_0.converter.ProductSpecificationDTOConverter)";

	public static final String SKU_DTO_CONVERTER =
		"(component.name=com.liferay.headless.commerce.admin.catalog." +
			"internal.dto.v1_0.converter.SkuDTOConverter)";

	public static final String SKU_UNIT_OF_MEASURE_DTO_CONVERTER =
		"(component.name=com.liferay.headless.commerce.admin.catalog." +
			"internal.dto.v1_0.converter.SkuUnitOfMeasureDTOConverter)";

}
